@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
 import simplejson
-from jukebox_core import api
-from jukebox_core.tests.api import ApiTestBase
+from jukebox.jukebox_core import api
+from jukebox.jukebox_core.tests.api import ApiTestBase
 
 # ATTENTION: order tests
 # favourites are ordered by insertion date DESC per default
